==> dmail-1.14.tgz: dmail/globals.c <==

/*
 * GLOBALS.C
 *
 *  Declarations for most global variables.
 *
 */

#include "dmail.h"

Prototype char *mail_file;                    /* name of from (spool) file    */
Prototype char *output_file;                  /* name of out file (i.e. mbox) */
Prototype char *user_name;                    /* user name from password entry*/
Prototype char *home_dir;                     /* home directory of user       */
Prototype char *visual;                       /* visual editor path           */
Prototype char Buf[MAXFIELDSIZE];             /* Scratch Buffer               */
Prototype char Puf[MAXFIELDSIZE];             /* Another Scratch Buffer       */
Prototype jmp_buf env[LONGSTACK];             /* Holds longjump (break) stack */
Prototype int  Did_cd;                        /* Set if user does a CD        */
Prototype int  XDebug;                        /* Debug mode                   */
Prototype int  Longstack, Breakstack;         /* longjump/break level stack   */
Prototype int  MaxEntries, Entries, Current;  /* #Entries and Current entry   */
Prototype int  XDisable;                      /* Disable non-cond comm exec.  */
Prototype int  ac;                            /* internal argc, from/to stat  */
Prototype int  No_load_mail;                  /* disable loading of mail      */
Prototype int  lmessage_overide;              /* Overide initial 'X items ... */
Prototype int  Silence;                       /* -s command option status     */
Prototype int  TruncateOnly;
Prototype int  ChangesMade;
Prototype struct ENTRY *Entry;                /* Base of Entry list           */
Prototype char *av[128];                      /* internal argv[]              */
Prototype char *Nulav[3];

Prototype int width[MAXLIST];
Prototype int header[MAXLIST];
Prototype int Listsize;

/* The following are globals variables definable from the 'set' command */

Prototype char  *S_sendmail;                  /* sendmail program path        */
Prototype int   S_page;                       /* Paging status                */
Prototype int   S_novibreak;                  /* vi-break status              */
Prototype int   S_verbose;                    /* sendmail verbose status      */
Prototype int   S_ask;                        /* Ask what to do after mail ed */
Prototype int   S_archive;                    /* Archive sent mail            */



char *mail_file;                    /* name of from (spool) file    */
char *output_file;                  /* name of out file (i.e. mbox) */
char *user_name;                    /* user name from password entry*/
char *home_dir;                     /* home directory of user       */
char *visual;                       /* visual editor path           */
char Buf[MAXFIELDSIZE];             /* Scratch Buffer               */
char Puf[MAXFIELDSIZE];             /* Another Scratch Buffer       */
jmp_buf env[LONGSTACK];             /* Holds longjump (break) stack */
int  Did_cd;                        /* Set if user does a CD        */
int  XDebug;                        /* Debug mode                   */
int  Longstack, Breakstack;         /* longjump/break level stack   */
int  MaxEntries;		    /* maximum number of entries    */
int  Entries, Current;              /* #Entries and Current entry   */
int  XDisable;                      /* Disable non-cond comm exec.  */
int  ac;                            /* internal argc, from/to stat  */
int  No_load_mail;                  /* disable loading of mail      */
int  lmessage_overide;              /* Overide initial 'X items ... */
int  Silence;                       /* -s command option status     */
int  TruncateOnly;
int  ChangesMade;
struct ENTRY *Entry;                /* Base of Entry list           */
char *av[128];                      /* internal argv[]              */
char *Nulav[3] = { "", "", NULL };

int width[MAXLIST]  = { 18, 38, 10 };   /* Default setlist params       */
int header[MAXLIST] = {  0,  2,  1 };
int Listsize = 3;

/* The following are globals variables definable from the 'set' command */

char  *S_sendmail;                  /* sendmail program path        */
int   S_page;                       /* Paging status                */
int   S_novibreak;                  /* vi-break status              */
int   S_verbose;                    /* sendmail verbose status      */
int   S_ask;                        /* Ask what to do after mail ed */
int   S_archive;                    /* Archive sent mail            */

==> dmail-1.21.tgz: dmail/globals.c <==

/*
 * GLOBALS.C
 *
 *  Declarations for most global variables.
 *
 */

#include "dmail.h"

Prototype char *mail_file;                    /* name of from (spool) file    */
Prototype char *output_file;                  /* name of out file (i.e. mbox) */
Prototype char *user_name;                    /* user name from password entry*/
Prototype char *home_dir;                     /* home directory of user       */
Prototype char *visual;                       /* visual editor path           */
Prototype char Buf[MAXFIELDSIZE];             /* Scratch Buffer               */
Prototype char Puf[MAXFIELDSIZE];             /* Another Scratch Buffer       */
Prototype jmp_buf env[LONGSTACK];             /* Holds longjump (break) stack */
Prototype int  Did_cd;                        /* Set if user does a CD        */
Prototype int  XDebug;                        /* Debug mode                   */
Prototype int  Longstack, Breakstack;         /* longjump/break level stack   */
Prototype int  MaxEntries, Entries, Current;  /* #Entries and Current entry   */
Prototype int  XDisable;                      /* Disable non-cond comm exec.  */
Prototype int  ac;                            /* internal argc, from/to stat  */
Prototype int  No_load_mail;                  /* disable loading of mail      */
Prototype int  lmessage_overide;              /* Overide initial 'X items ... */
Prototype int  Silence;                       /* -s command option status     */
Prototype int  TruncateOnly;
Prototype int  ChangesMade;
Prototype struct ENTRY *Entry;                /* Base of Entry list           */
Prototype char *av[128];                      /* internal argv[]              */
Prototype char *Nulav[3];

Prototype int width[MAXLIST];
Prototype int header[MAXLIST];
Prototype int Listsize;

/* The following are globals variables definable from the 'set' command */

Prototype char  *S_sendmail;        /* sendmail program path        */
Prototype int   S_page;             /* Paging status                */
Prototype int   S_novibreak;        /* vi-break status              */
Prototype int   S_verbose;          /* sendmail verbose status      */
Prototype int   S_ask;              /* Ask what to do after mail ed */
Prototype int   S_archive;          /* Archive sent mail            */
Prototype int   S_quiet;            /* Try to be quiet	      	    */



char *mail_file;                    /* name of from (spool) file    */
char *output_file;                  /* name of out file (i.e. mbox) */
char *user_name;                    /* user name from password entry*/
char *home_dir;                     /* home directory of user       */
char *visual;                       /* visual editor path           */
char Buf[MAXFIELDSIZE];             /* Scratch Buffer               */
char Puf[MAXFIELDSIZE];             /* Another Scratch Buffer       */
jmp_buf env[LONGSTACK];             /* Holds longjump (break) stack */
int  Did_cd;                        /* Set if user does a CD        */
int  XDebug;                        /* Debug mode                   */
int  Longstack, Breakstack;         /* longjump/break level stack   */
int  MaxEntries;		    /* maximum number of entries    */
int  Entries, Current;              /* #Entries and Current entry   */
int  XDisable;                      /* Disable non-cond comm exec.  */
int  ac;                            /* internal argc, from/to stat  */
int  No_load_mail;                  /* disable loading of mail      */
int  lmessage_overide;              /* Overide initial 'X items ... */
int  Silence;                       /* -s command option status     */
int  TruncateOnly;
int  ChangesMade;
struct ENTRY *Entry;                /* Base of Entry list           */
char *av[128];                      /* internal argv[]              */
char *Nulav[3] = { "", "", NULL };

int width[MAXLIST]  = { 18, 38, 10 };   /* Default setlist params       */
int header[MAXLIST] = {  0,  2,  1 };
int Listsize = 3;

/* The following are globals variables definable from the 'set' command */

char  *S_sendmail;              /* sendmail program path        */
int   S_page;                   /* Paging status                */
int   S_novibreak;              /* vi-break status              */
int   S_verbose;                /* sendmail verbose status      */
int   S_ask;                    /* Ask what to do after mail ed */
int   S_archive;                /* Archive sent mail            */
int   S_quiet;			/* Try to be quiet		*/
